@@ -24,6 +24,9 @@ import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.MavenRepositoryMetadata;
 import org.guvnor.common.services.project.model.MavenRepositorySource;
 import org.guvnor.common.services.project.model.POM;
+import org.guvnor.common.services.project.model.WorkspaceProject;
+import org.guvnor.common.services.project.service.BaseArchetypeService;
+import org.guvnor.common.services.project.service.DeploymentMode;
 import org.guvnor.common.services.project.service.GAVAlreadyExistsException;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.rest.client.JobResult;
@@ -63,6 +66,9 @@ public class JobRequestHelperCreateModuleTest {
     @Mock
     private OrganizationalUnitService organizationalUnitService;
 
+    @Mock
+    private BaseArchetypeService archetypeService;
+
     @InjectMocks
     private JobRequestHelper jobRequestHelper = new JobRequestHelper();
 
@@ -70,7 +76,7 @@ public class JobRequestHelperCreateModuleTest {
     public void setUp() throws Exception {
         fileSystemProvider = new SimpleFileSystemProvider();
 
-        final Path root = fileSystemProvider.getPath(URI.create("default://master@myRepository/"));
+        final Path root = fileSystemProvider.getPath(URI.create("default://main@myRepository/"));
 
         OrganizationalUnit ou = mock(OrganizationalUnit.class);
         when(organizationalUnitService.getOrganizationalUnit(any())).thenReturn(ou);
@@ -98,6 +104,9 @@ public class JobRequestHelperCreateModuleTest {
 
     @Test
     public void testRepositoryDoesExist() throws Exception {
+        when(workspaceProjectService.newProject(any(OrganizationalUnit.class),
+                                                any(POM.class)))
+                .thenReturn(mock(WorkspaceProject.class));
         final JobResult jobResult = jobRequestHelper.createProject("jobId",
                                                                    "spaceName",
                                                                    "projectName",
@@ -109,6 +118,25 @@ public class JobRequestHelperCreateModuleTest {
                      jobResult.getJobId());
         assertEquals(JobStatus.SUCCESS,
                      jobResult.getStatus());
+        assertNotNull(jobResult.getResult());
+    }
+
+    @Test
+    public void testNullWorkspaceProject() throws Exception {
+        when(workspaceProjectService.newProject(any(OrganizationalUnit.class),
+                                                any(POM.class)))
+                .thenReturn(null);
+        final JobResult jobResult = jobRequestHelper.createProject("jobId",
+                                                                   "spaceName",
+                                                                   "projectName",
+                                                                   "projectGroupId",
+                                                                   "projectVersion",
+                                                                   "projectDescription");
+
+        assertEquals("jobId",
+                     jobResult.getJobId());
+        assertEquals(JobStatus.FAIL,
+                     jobResult.getStatus());
         assertNull(jobResult.getResult());
     }
 
@@ -162,6 +190,58 @@ public class JobRequestHelperCreateModuleTest {
                      jobResult.getResult());
     }
 
+    @Test
+    public void testProjectWithTemplates() {
+
+        when(workspaceProjectService.newProject(any(OrganizationalUnit.class),
+                any(POM.class),
+                eq(DeploymentMode.VALIDATED),
+                eq(null),
+                any(Repository.class))).thenReturn(mock(WorkspaceProject.class));
+        when(archetypeService.getTemplateRepository(any(),
+                any())).thenReturn(mock(Repository.class));
+
+        final JobResult jobResult = jobRequestHelper.createProject("jobId",
+                "myOrganizationalUnit",
+                "myProject",
+                "projectGroupId",
+                "projectVersion",
+                "projectDescription",
+                "org.kie.kie.drools.archetype.7.55.0.SNAPSHOT.TEMPLATE");
+
+        assertEquals("jobId",
+                jobResult.getJobId());
+        assertEquals(JobStatus.SUCCESS,
+                jobResult.getStatus());
+        assertNotNull(jobResult.getResult());
+    }
+
+    @Test
+    public void testProjectWithTemplatesNotAvailable() {
+
+        doThrow(new IllegalArgumentException("Template is not available"))
+                .when(workspaceProjectService).newProject(any(OrganizationalUnit.class),
+                                                            any(POM.class),
+                                                            eq(DeploymentMode.VALIDATED),
+                                                            eq(null),
+                                                            any(Repository.class));
+        when(archetypeService.getTemplateRepository(any(),
+                                                    any())).thenReturn(mock(Repository.class));
+        final JobResult jobResult = jobRequestHelper.createProject("jobId",
+                "myOrganizationalUnit",
+                "myProject",
+                "projectGroupId",
+                "projectVersion",
+                "projectDescription",
+                "org.kie.kie.drools.archetype.7.55.0.SNAPSHOT.TEMPLATE");
+        assertEquals("jobId",
+                jobResult.getJobId());
+        assertEquals(JobStatus.FAIL,
+                jobResult.getStatus());
+        assertEquals(jobResult.getResult(),
+                "Template is not available");
+    }
+
     @Test
     public void testWeAreUsingCorrectGAV() throws Exception {
 
